
import sys
import os
import pandas as pd
import json


sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
  
from JGTIDS import _ids_add_fdb_column_logics_v2

from JGTIDSRequest import JGTIDSRequest

from jgtapyhelper import createIDSService
import jgtapyhelper as th

#@STCGoal Wrap the JGTIDS and jgtapyhelper classes into a service class


def get_ids(rq:JGTIDSRequest):
    try:
      idspath, idf=createIDSService(
                    rq=rq,
                    quiet=rq.quiet,
                    verbose_level=rq.verbose_level,
                )
      idf=_ids_add_fdb_column_logics_v2(idf)
      return idf
        
    except:
      print("IDS failed")
      return None
    
  


import argparse
import json
class JGTBaseRequest:
    def __init__(self, quiet=True, verbose_level=0,viewpath=False):
        self.quiet = quiet
        self.verbose_level = verbose_level
        self.viewpath = viewpath
    
    def __from_args__(self, args: argparse.Namespace):
        self.quiet = args.quiet
        self.verbose_level = args.verbose
        self.viewpath = args.viewpath
        
    # create a new JGTBaseRequest object from args (argparse)
    @staticmethod
    def from_args(args):
        instance=JGTBaseRequest(       )
        instance.__from_args__(args)
        return instance
    
    def __from_json__(self, json_str):
        #set values from json foreach of the keys included in the json_str
        try:
            json_obj=json.loads(json_str)
            for key in json_obj:
                setattr(self, key, json_obj[key])
        except Exception as e:
            print("ERROR(JGTBaseRequest): from_json", e)
            print("ERROR(JGTBaseRequest): from_json", json_str)
        
    
    @staticmethod
    def from_json(json_str):
        return json.loads(json_str)
    
    def to_json(self):
        return json.dumps(self, default=lambda o: o.__dict__, sort_keys=False, indent=2)
    



import warnings

# Ignore FutureWarning
warnings.simplefilter(action="ignore", category=FutureWarning)

import sys
import os

sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))

from JGTIDSRequest import JGTIDSRequest

from jgtutils.jgtconstants import (
    IDS_COLUMNS_TO_NORMALIZE
)

columns_to_normalize = IDS_COLUMNS_TO_NORMALIZE  # @a Migrate to jgtutils.jgtconstants

from jgtutils import (
    jgtcommon as jgtcommon,
)

from jgtapyhelper import createIDSService,print_quiet




# @STCGoal CLI

import argparse

def _parse_args():
    from jgtpyconstants import IDSCLI_PROG_DESCRIPTION, IDSCLI_PROG_NAME, IDSCLI_PROG_EPILOG
    parser=jgtcommon.new_parser(IDSCLI_PROG_DESCRIPTION,prog=IDSCLI_PROG_NAME,epilog=IDSCLI_PROG_EPILOG)
    # jgtfxcommon.add_main_arguments(parser)
    jgtcommon.add_instrument_timeframe_arguments(parser)
    # jgtcommon.add_date_arguments(parser)
    # jgtcommon.add_tlid_range_argument(parser)
    #add_bars_amount_V2_arguments
    jgtcommon.add_bars_amount_V2_arguments(parser)
    # jgtcommon.add_output_argument(parser)
    # jgtfxcommon.add_quiet_argument(parser)
    jgtcommon.add_verbose_argument(parser)

    jgtcommon.add_use_fresh_argument(parser)
    jgtcommon.add_keepbidask_argument(parser)
    jgtcommon.add_ids_mfi_argument(parser)
    jgtcommon.add_ids_gator_oscillator_argument(parser)
    jgtcommon.add_ids_balligator_argument(parser)
    jgtcommon.add_ids_talligator_argument(parser)
    jgtcommon.add_ids_fractal_largest_period_argument(parser)
    
    jgtcommon.add_dropna_volume_argument(parser)

    jgtcommon.add_viewpath_argument(parser)
    # parser.add_argument(
    #     "-go",
    #     "--gator_oscillator_flag",
    #     action="store_true",
    #     help="Enable the Gator Oscillator indicator.",
    # )
    # parser.add_argument(
    #     "-mfi",
    #     "--mfi_flag",
    #     action="store_true",
    #     help="Enable the Market Facilitation Index indicator.",
    # )

    parser.add_argument(
        "--bypass_index_reset",
        action="store_true",
        help="Bypass resetting the index.",
    )

    # parser.add_argument(
    #     "-ba",
    #     "--balligator_flag",
    #     action="store_true",
    #     help="Enable the Alligator indicator.",
    # )
    # parser.add_argument(
    #     "-bjaw",
    #     "--balligator_period_jaws",
    #     type=int,
    #     default=89,
    #     help="The period of the Alligator jaws.",
    # )
    # parser.add_argument(
    #     "-lfp",
    #     "--largest_fractal_period",
    #     type=int,
    #     default=89,
    #     help="The largest fractal period.",
    # )
    args = jgtcommon.parse_args(parser)
    return args


def main():


    rq = JGTIDSRequest()
    args = _parse_args()

    # There might be multiple for now
    instrument = args.instrument
    timeframe = args.timeframe

    verbose_level = args.verbose
    #viewpath=args.viewpath
    
    quiet = False
    if verbose_level == 0:
        quiet = True


    process_ids = True

    if process_ids:
        if not quiet:
            print("Processing IDS")
        output = True


    try:

        print_quiet(quiet, "Getting for : " + instrument + "_" + timeframe)
        instruments = instrument.split(",")
        timeframes = timeframe.split(",")

        for instrument in instruments:
            for timeframe in timeframes:
                rq = JGTIDSRequest.from_args(args)
                rq.instrument=instrument
                rq.timeframe=timeframe
                createIDSService(
                    rq=rq,
                    quiet=quiet,
                    verbose_level=verbose_level,
                )

    except Exception as e:
        jgtcommon.print_exception(e)




if __name__ == "__main__":
    main()




import sys
import os
import copy
import json


sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))

from JGTCDSRequest import JGTCDSRequest
from JGTChartConfig import JGTChartConfig


class JGTADSRequest(JGTCDSRequest):
    def __init__(self,
                 plot_ao_peaks=True, 
                 show=False, 
                 nb_bar_on_chart=None, 
                 min_bar_on_chart=None, 
                 cds_required_amount_of_bar_for_calc=None, 
                 nb_bar_to_retrieve=None,
                 tlid_range:str=None, 
                 cc:JGTChartConfig=None,
                 save_additional_figures_path:str=None,
                 save_additional_figures_dpi=300,
                 show_plain_plot=False,
                 show_feature_one_plot=False,
                 show_feature_two_plot=False,
                 show_feature_2403_plot=False,
                 save_figure_as_pov:bool=False,
                 save_figure_as_timeframe:bool=False,
                 *args, 
                 **kwargs):
        super().__init__(*args, **kwargs)
        
        #largest_fractal_period
        
        if cc is None:
            self.cc = JGTChartConfig()
            self.show_feature_one_plot = show_feature_one_plot
            self.show_feature_two_plot = show_feature_two_plot
            self.show_plain_plot = show_plain_plot
            self.show_feature_2403_plot = show_feature_2403_plot
            self.set_feature_one_plot(show_feature_one_plot)
            self.set_feature_two_plot(show_feature_two_plot)
            self.set_plain_plot(show_plain_plot)
            self.set_feature_2403_plot(show_feature_2403_plot)
        else:
            self.cc = cc
            self.show_feature_one_plot = cc.show_feature_one_plot
            self.show_feature_two_plot = cc.show_feature_two_plot
            self.show_feature_2403_plot = cc.show_feature_2403_plot
            self.show_plain_plot = cc.show_plain_plot
        
        self.tlid_range = tlid_range
        if self.tlid_range is not None:
            print("-- Possible Extension for a request with a TLID range in which we would generates various charts of signaling moments--")
        
        self.save_additional_figures_path = save_additional_figures_path
        self.save_additional_figures_dpi = save_additional_figures_dpi
        
        self.plot_ao_peaks = plot_ao_peaks
        self.show = show
        #self.big_alligator_flag = big_alligator_flag
        
        
        
        # IMPORTED from JGTChartConfig (Migrating from JGTChartConfig to JGTADSRequest)
        if nb_bar_on_chart is not None:
            self.cc.nb_bar_on_chart = nb_bar_on_chart
        self.nb_bar_on_chart = self.cc.nb_bar_on_chart
            
        if min_bar_on_chart is not None:
            self.cc.min_bar_on_chart = min_bar_on_chart
        self.min_bar_on_chart = self.cc.min_bar_on_chart
            
        if cds_required_amount_of_bar_for_calc is not None:
            self.cc.cds_required_amount_of_bar_for_calc = cds_required_amount_of_bar_for_calc
        self.cds_required_amount_of_bar_for_calc = self.cc.cds_required_amount_of_bar_for_calc
        
        
        self.cds_required_amount_of_bar_for_calc = cds_required_amount_of_bar_for_calc if cds_required_amount_of_bar_for_calc is not None else self.balligator_period_jaws
        
        self.nb_bar_to_retrieve = nb_bar_to_retrieve if nb_bar_to_retrieve is not None else self.nb_bar_on_chart + self.cds_required_amount_of_bar_for_calc
        
        
        self.save_figure_as_pov=save_figure_as_pov
        self.save_figure_as_timeframe=save_figure_as_timeframe
        
        #@STCIssue Fix quotescount 
        if self.nb_bar_to_retrieve< self.quotescount:
            self.nb_bar_to_retrieve = self.quotescount
        
        #if self.balligator_period_jaws == 0 and self.largest_fractal_period != 0:
        #    self.cds_required_amount_of_bar_for_calc = self.largest_fractal_period
            
        
        #self.reset()
    
    def set_feature_2403_plot(self, value:bool):
        self.show_feature_2403_plot = value
        self.cc.show_feature_2403_plot = value
        #self.reset()
    
    def set_feature_one_plot(self, value:bool):
        self.show_feature_one_plot = value
        self.cc.show_feature_one_plot = value
        #self.reset()
        
    def set_feature_two_plot(self, value:bool):
        self.show_feature_two_plot = value
        self.cc.show_feature_two_plot = value
        
    def set_plain_plot(self, value:bool):
        self.show_plain_plot = value
        self.cc.show_plain_plot = value
        #self.reset()
     
    def reset(self):
        
        #self.cc.reset()
        
        #@STCIssue Backward compatibility for using cc
        # self.cc.nb_bar_on_chart = self.nb_bar_on_chart
        # self.cc.min_bar_on_chart = self.min_bar_on_chart
        
        self.balligator_period_jaws = self.cc.balligator_period_jaws 
        #self.cc.cds_required_amount_of_bar_for_calc = self.cds_required_amount_of_bar_for_calc
        self.nb_bar_to_retrieve = self.cc.nb_bar_to_retrieve
    
    def copy(self):
        return copy.copy(self)
        # _cp= JGTADSRequest(self.plot_ao_peaks, self.show, self.nb_bar_on_chart, self.min_bar_on_chart, self.cds_required_amount_of_bar_for_calc, self.nb_bar_to_retrieve, self.tlid_range, self.cc)
        # _cp.super = super().__copy__()
    
    def copy_with_timeframe(self, timeframe:str):
        _cp = self.copy()
        _cp.timeframe = timeframe
        return _cp
    
    def to_json(self,filename:str=None):
        json_o = json.dumps(self, default=lambda o: o.__dict__, sort_keys=True, indent=2)
        if filename is not None:
            with open(filename, 'w') as f:
                f.write(json_o)
        return json_o
    
    @staticmethod
    def from_json(json_str:str):
        return json.loads(json_str)
    
    @staticmethod
    def new_feature_plot(instrument,timeframe,feature_plot:int, save_additional_figures_path=None,show=False,*args, **kwargs):
        cc = JGTChartConfig.new_feature_plot(feature_plot)
        return JGTADSRequest(instrument=instrument,timeframe=timeframe,cc=cc,save_additional_figures_path=save_additional_figures_path,show=show,*args, **kwargs)
        
# Create an instance with default values
default_config = JGTADSRequest()





import json


class JGTChartConfig:
    def __init__(self, 
                 nb_bar_on_chart=300, min_bar_on_chart=299, balligator_period_jaws=89, 
                 cds_required_amount_of_bar_for_calc=None, 
                 nb_bar_to_retrieve=None, 
                 show_grid=False, subtitle_x_pos=0.07, subtitle_y_pos=0.9, subtitle_ha="left", subtitle_fontsize=10, title_x_pos=0.055, title_y_pos=0.96, title_ha="left", title_fontsize=14, jaw_line_width=1, teeth_line_width=1, lips_line_width=1, fig_ratio_x=24, fig_ratio_y=14, fdb_marker_size=7, fractal_marker_size=6, ac_signals_marker_size=32, saucer_marker_size=16, fractal_degreehigher_marker_size=20, fractal_ultra_degreehigher_marker_size=26,price_peak_marker_size=36, ao_peaks_marker_size=42, fdb_signal_marker="o", 
                 fractal_up_marker="^", 
                 fractal_up_marker_higher="^", 
                 fractal_dn_marker_higher="v", 
                 fractal_dn_marker="v", ac_signal_marker="o", 
                 acb_plot_type="scatter", 
                 ao_peak_above_marker_higher="^", ao_peak_bellow__marker_higher="v", 
                 saucer_marker="|", zcol_marker="|", 
                 aop_bellow_color="r", 
                 aop_above_color="g", 
                 ao_upbar_color="g", ao_dnbar_color="r", ac_up_color="darkgreen", ac_dn_color="darkred", fdb_signal_buy_color="g", fdb_signal_sell_color="r", jaw_color="blue", teeth_color="red", lips_color="green", 
                 fractal_up_color="blue", 
                 fractal_dn_color="blue", 
                 fractal_dn_color_higher="blue", 
                 fractal_up_color_higher="blue", 
                 fractal_dn_color_ultra_higher="blue", 
                 fractal_up_color_ultra_higher="blue", 
                 ac_signal_buy_color="lightgreen", 
                 ac_signal_sell_color="yellow", 
                 saucer_buy_color="g", 
                 saucer_sell_color="r", 
                 price_peak_bellow_marker="o", 
                 price_peak_above_marker="o", 
                 price_peak_above_color="g", 
                 price_peak_bellow_color="r", 
                 ao_peak_offset_value=0, 
                 plot_style="yahoo", 
                 ao_plot_type="bar", 
                 ac_plot_type="bar", 
                 main_plot_panel_id=0, 
                 ao_plot_panel_id=1, 
                 ac_plot_panel_id=2,
                 main_plot_type="ohlc",
                 show_plain_plot=False,
                 show_feature_one_plot=False,
                 show_feature_two_plot=False,
                 show_feature_2403_plot=False,
                 show_fractal=True,
                 show_fractal_higher=True,
                 show_fractal_ultra_higher=False,
                 show_fdb_signal=True,
                 show_ac_signal=True,
                 show_saucer=True,
                 show_price_peak=True,
                 show_ao_peaks=True,
                 show_ao=True,
                 show_ac=True,
                 show_alligator=True,
                 show_zlc=True,
                 fractal_high_degree=8,
                 fractal_ultra_high_degree=21,
                 show_feature_one_plot_var2=False):
        
        self.fractal_high_degree = fractal_high_degree     
        self.fractal_ultra_high_degree = fractal_ultra_high_degree   
        self.show_fractal_ultra_higher = show_fractal_ultra_higher
        self.main_plot_type = main_plot_type
        self.show_fractal = show_fractal
        self.show_fractal_higher = show_fractal_higher
        self.show_fdb_signal = show_fdb_signal
        self.show_ac_signal = show_ac_signal
        self.show_saucer = show_saucer
        self.show_price_peak = show_price_peak
        self.show_ao_peaks = show_ao_peaks
        self.show_ao = show_ao
        self.show_ac = show_ac
        self.show_zlc = show_zlc
        self.show_alligator = show_alligator
        self.show_plain_plot = show_plain_plot
        self.show_feature_one_plot = show_feature_one_plot
        self.show_feature_two_plot = show_feature_two_plot
        self.show_feature_2403_plot = show_feature_2403_plot
        self.show_feature_one_plot_var2 = show_feature_one_plot_var2

        
        self.nb_bar_on_chart = nb_bar_on_chart
        self.min_bar_on_chart = min_bar_on_chart
        self.balligator_period_jaws = balligator_period_jaws
        self.cds_required_amount_of_bar_for_calc = cds_required_amount_of_bar_for_calc if cds_required_amount_of_bar_for_calc is not None else self.balligator_period_jaws
        self.nb_bar_to_retrieve = nb_bar_to_retrieve if nb_bar_to_retrieve is not None else self.nb_bar_on_chart + self.cds_required_amount_of_bar_for_calc
        self.show_grid = show_grid
        self.subtitle_x_pos = subtitle_x_pos
        self.subtitle_y_pos = subtitle_y_pos
        self.subtitle_ha = subtitle_ha
        self.subtitle_fontsize = subtitle_fontsize
        self.title_x_pos = title_x_pos
        self.title_y_pos = title_y_pos
        self.title_ha = title_ha
        self.title_fontsize = title_fontsize
        self.jaw_line_width = jaw_line_width
        self.teeth_line_width = teeth_line_width
        self.lips_line_width = lips_line_width
        self.fig_ratio_x = fig_ratio_x
        self.fig_ratio_y = fig_ratio_y
        self.fdb_marker_size = fdb_marker_size
        self.fractal_marker_size = fractal_marker_size
        self.ac_signals_marker_size = ac_signals_marker_size
        self.saucer_marker_size = saucer_marker_size
        self.fractal_degreehigher_marker_size = fractal_degreehigher_marker_size
        self.fractal_ultra_degreehigher_marker_size = fractal_ultra_degreehigher_marker_size
        self.price_peak_marker_size = price_peak_marker_size
        self.ao_peaks_marker_size = ao_peaks_marker_size
        self.fdb_signal_marker = fdb_signal_marker
        self.fractal_up_marker = fractal_up_marker
        self.fractal_up_marker_higher = fractal_up_marker_higher
        self.fractal_dn_marker_higher = fractal_dn_marker_higher
        self.fractal_dn_marker = fractal_dn_marker
        self.ac_signal_marker = ac_signal_marker
        self.acb_plot_type = acb_plot_type
        self.ao_peak_above_marker_higher = ao_peak_above_marker_higher
        self.ao_peak_bellow__marker_higher = ao_peak_bellow__marker_higher
        self.saucer_marker = saucer_marker
        self.zcol_marker = zcol_marker
        self.aop_bellow_color = aop_bellow_color
        self.aop_above_color = aop_above_color
        self.ao_upbar_color = ao_upbar_color
        self.ao_dnbar_color = ao_dnbar_color
        self.ac_up_color = ac_up_color
        self.ac_dn_color = ac_dn_color
        self.fdb_signal_buy_color = fdb_signal_buy_color
        self.fdb_signal_sell_color = fdb_signal_sell_color
        self.jaw_color = jaw_color
        self.teeth_color = teeth_color
        self.lips_color = lips_color
        self.fractal_up_color = fractal_up_color
        self.fractal_dn_color = fractal_dn_color
        
        self.fractal_dn_color_higher = fractal_dn_color_higher
        self.fractal_up_color_higher = fractal_up_color_higher
        
        self.fractal_dn_color_ultra_higher = fractal_dn_color_ultra_higher
        self.fractal_up_color_ultra_higher = fractal_up_color_ultra_higher
        
        self.ac_signal_buy_color = ac_signal_buy_color
        self.ac_signal_sell_color = ac_signal_sell_color
        self.saucer_buy_color = saucer_buy_color
        self.saucer_sell_color = saucer_sell_color
        self.price_peak_bellow_marker = price_peak_bellow_marker
        self.price_peak_above_marker = price_peak_above_marker
        self.price_peak_above_color = price_peak_above_color
        self.price_peak_bellow_color = price_peak_bellow_color
        self.ao_peak_offset_value = ao_peak_offset_value
        self.plot_style = plot_style
        self.ao_plot_type = ao_plot_type
        self.ac_plot_type = ac_plot_type
        self.main_plot_panel_id = main_plot_panel_id
        self.ao_plot_panel_id = ao_plot_panel_id
        self.ac_plot_panel_id = ac_plot_panel_id
        
        self.reset()
        
    def reset(self): #@STCIssue This is confusing, renaming it update
        self.update()
    
    def update(self):
        
        if self.show_feature_2403_plot:
            self.show_ac = False
            self.show_fractal = False
        
        # To create simple chart
        if self.show_plain_plot:
            self.show_fractal = False
            self.show_ac = False
            self.show_fractal_higher = False
            self.show_fdb_signal = False
            self.show_ac = False
            self.show_alligator = False
            self.show_ao = False
            self.show_price_peak = False
            self.show_saucer = False
            self.show_ao_peaks = False
            self.show_zlc = False
            
        
        if self.show_feature_one_plot:
            self.show_fractal_higher = True
            self.show_fractal = False
            self.show_fdb_signal = True
            self.show_alligator = True
            self.show_ac = False
            self.show_ao = True
            self.show_price_peak = True
            self.show_saucer = False
            self.show_ao_peaks = True
            self.show_zlc = True
        
        if self.show_feature_one_plot_var2:
            self.show_fractal_higher = True
            self.show_fractal = True
            self.show_fdb_signal = True
            self.show_alligator = True
            self.show_ac = False
            self.show_ao = True
            self.show_price_peak = True
            self.show_saucer = False
            self.show_ao_peaks = True
            self.show_zlc = True
            
        if self.show_feature_two_plot:                        
            self.show_ac=False
            self.show_fractal=False
            self.show_fractal_higher = True
            self.show_fdb_signal = True
            self.show_alligator = True
            self.show_ao = True
            self.show_price_peak = True
            self.show_ao_peaks = True
            
        # turn back flags on if they are off
        if self.show_ac is False:
            self.show_ac_signal = False
            
        if self.show_ao is False:
            self.show_ao_peaks = False
            self.show_saucer = False
            self.show_zlc = False
            #print("ShowAO is False")

    def to_json(self):
        return json.dumps(self.__dict__)
    
    @staticmethod
    def new_feature_plot(feature_plot=1):
        cc = JGTChartConfig()
        cc.show_feature_one_plot = True if feature_plot == 1 else False
        cc.show_feature_one_plot_var2 = True if feature_plot == 11 else False
        cc.show_feature_two_plot = True if feature_plot == 2 else False
        cc.show_feature_2403_plot = True if feature_plot == 3 else False
        cc.update()
        return cc
    # def __str__(self) -> str:
    #     return f"JGTChartConfig(nb_bar_on_chart={self.nb_bar_on_chart}, min_bar_on_chart={self.min_bar_on_chart}, balligator_period_jaws={self.balligator_period_jaws}, cds_required_amount_of_bar_for_calc={self.cds_required_amount_of_bar_for_calc}, nb_bar_to_retrieve={self.nb_bar_to_retrieve}, show_grid={self.show_grid}, subtitle_x_pos={self.subtitle_x_pos}, subtitle_y_pos={self.subtitle_y_pos}, subtitle_ha={self.subtitle_ha}, subtitle_fontsize={self.subtitle_fontsize}, title_x_pos={self.title_x_pos}, title_y_pos={self.title_y_pos}, title_ha={self.title_ha}, title_fontsize={self.title_fontsize}, jaw_line_width={self.jaw_line_width}, teeth_line_width={self.teeth_line_width}, lips_line_width={self.lips_line_width}, fig_ratio_x={self.fig_ratio_x}, fig_ratio_y={self.fig_ratio_y}, fdb_marker_size={self.fdb_marker_size}, fractal_marker_size={self.fractal_marker_size}, ac_signals_marker_size={self.ac_signals_marker_size}, saucer_marker_size={self.saucer_marker_size}, fractal_degreehigher_marker_size={self.fractal_degreehigher_marker_size}, price_peak_marker_size={self.price_peak_marker_size}, ao_peaks_marker_size={self.ao_peaks_marker_size}, fdb_signal_marker={self.fdb_signal_marker}, fractal_up_marker={self.fractal_up_marker}, fractal_up_marker_higher={self.fractal_up_marker_higher}, fractal_dn_marker_higher={self.fractal_dn_marker_higher}, fractal_dn_marker={self.fractal_dn_marker}, ac_signal_marker={self.ac_signal_marker}, acb_plot_type={self.acb_plot_type}, ao_peak_above_marker_higher={self.ao_peak_above_marker_higher}, ao_peak_bellow__marker_higher={self.ao_peak_bellow__marker_higher}, saucer_marker={self.saucer_marker}, zcol_marker={self.zcol_marker}, aop_bellow_color={self.aop_bellow_color}, aop_above_color={self.aop_above_color}, ao_upbar_color={self.ao_upbar_color}, ao_dnbar_color={self.ao_dnbar_color}, ac_up_color={self.ac_up_color}, ac_dn_color={self.ac_dn_color}, fdb_signal_buy_color={self.fdb_signal_buy_color}, fdb_signal_sell_color={self.fdb_signal_sell_color}, jaw_color={self.jaw_color}, teeth_color={self.teeth_color}, lips_color={self.lips_color}, fractal_up_color={self.fractal_up_color}, fractal_dn_color={self.fractal_dn_color}, fractal_dn_color_higher={self.fractal_dn_color_higher}, fractal_up_color_higher={self.fractal_up_color_higher}, ac_signal_buy_color={self.ac_signal_buy_color}, ac_signal_sell_color={self.ac_signal_sell_color}, saucer_buy_color={self.saucer_buy_color}, saucer_sell_color={self.saucer_sell_color}, price_peak_bellow_marker={self.price_peak_bellow_marker}, price_peak_above_marker={self.price_peak_above_marker}, price_peak_above_color={self.price_peak_above_color}, price_peak_bellow_color={self.price_peak_bellow_color}, ao_peak_offset_value={self.ao_peak_offset_value}, plot_style={self.plot_style}, ao_plot_type={self.ao_plot_type}, ac_plot_type={self.ac_plot_type}, main_plot_panel_id={self.main_plot_panel_id}, ao_plot_panel_id={self.ao_plot_panel_id}, ac_plot_panel_id={self.ac_plot_panel_id})"


# Create an instance with default values
default_config = JGTChartConfig()



import argparse
import importlib.resources as pkg_resources
import os
import sys
from pathlib import Path

sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))

PACKAGE = 'jgtpy'
DOC_PATH = 'guide_for_llm_agents'

def _doc_dir():
    return pkg_resources.files(PACKAGE) / DOC_PATH

def list_sections():
    return [p.stem for p in _doc_dir().iterdir() if p.suffix == '.md']

def read_section(name: str) -> str:
    path = _doc_dir() / f"{name}.md"
    if path.is_file():
        return path.read_text()
    raise FileNotFoundError(f"Section {name} not found")

def main():
    parser = argparse.ArgumentParser(description="JGTPY documentation for LLM agents")
    parser.add_argument('--list', action='store_true', help='List available sections')
    parser.add_argument('--section', help='Display a specific section')
    parser.add_argument('--all', action='store_true', help='Display all sections')
    args = parser.parse_args()

    if args.list:
        for sec in list_sections():
            print(sec)
        return

    if args.all:
        for sec in list_sections():
            print(f"# {sec}\n")
            print(read_section(sec))
            print()
        return

    if args.section:
        print(read_section(args.section))
        return

    parser.print_help()

if __name__ == '__main__':
    main()



# import os
# #import jgtdotenv
# from dotenv import load_dotenv
# from dotenv import dotenv_values

# load_dotenv()  # take environment variables from .env.
# #env=load_dotenv(os.getenv(os.getcwd()))
# env = dotenv_values(".env")



# #@DEPRECATED
# if os.getenv('FXCM_TOKEN_REST_API_DEMO') == "":
#   load_dotenv(os.getenv('HOME'))
# if os.getenv('FXCM_TOKEN_REST_API_DEMO') == "":
#   load_dotenv(os.getenv(os.getcwd()))
# #@title TOKENS
# def getenv(tvar):
#   return os.getenv(tvar)



# #@DEPRECATED: 

# _FXCM_TOKEN_REST_API_DEMO = os.getenv('FXCM_TOKEN_REST_API_DEMO')
# _FXCM_TOKEN_REST_API_REAL = os.getenv('FXCM_TOKEN_REST_API_REAL')
# _FXCM_DROPBOX_ACCESS_TOKEN = os.getenv('FXCM_DROPBOX_ACCESS_TOKEN')
# _DROPBOX_ACCESS_TOKEN= _FXCM_DROPBOX_ACCESS_TOKEN
# # print(FXCM_TOKEN_REST_API_DEMO)

# local_fn_compression='gzip'


# pysroot=os.getenv('pysroot')
# #pysroot='/w/o/pys/'
# CDS_URL_BASE=os.getenv('CDS_URL_BASE')
# phurlbase=CDS_URL_BASE
# #phurlbase='https://ai.guillaumeisabelle.com/sds/datasets/cds/' #todo rename as pds, cds are going to be indicators/cds data

# DROPBOX_ETC_PATH= '/w/etc/'

# #@title Demo Token
# _tokendemo =_FXCM_TOKEN_REST_API_DEMO
# _tokenreal=_FXCM_TOKEN_REST_API_REAL

# _token=_tokendemo #default
# if os.getenv('usereal') == 'True' :
#   _token=_tokenreal
#   print('TRADING REAL ACTIVATED')

# def setreal():
#   global _token
#   _token=_tokenreal

# def setdemo():
#   global _token
#   _token=_tokendemo


# # %%
# contextInstruments=['AUD/CAD',
#  'AUD/JPY',
#  'AUD/USD',
#  'CAD/CHF',
#  'CAD/JPY',
#  'EUR/CAD',
#  'EUR/USD',
#  'GBP/CAD',
#  'GBP/USD',
#  'NAS100',
#  'NZD/CAD',
#  'NZD/USD',
#  'USD/CAD'
#  ]

# contextTimeframes=['m1','m5','m15']
# # contextTimeframes=['m1','m5','m15','H1','H4','D1','W1','M1']



#!/usr/bin/env python

import sys
import os



sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))

# import .

from jgtutils import (
    jgtconstants as constants,
    jgtcommon as jgtcommon,
)

import JGTCDS as cds
import JGTCDSSvc as svc

import pandas as pd

epilog = """
Proto usage:JGTPY_DATA=/tmp/fds;

jgtfxcli -i EUR/USD -t m5 -c 12000;

tlid_v=2409022200;python jgtpy/pds2cds.py -f /tmp/fds/pds/EUR-USD_m5 -c 500 -to $tlid_v -o /tmp/fds/pds/EUR-USD_m5.$tlid_v.cds.csv;
wc -l /tmp/fds/pds/EUR-USD_m5.$tlid_v.cds.csv;
tail -n 1 /tmp/fds/pds/EUR-USD_m5.$tlid_v.cds.csv
"""
def _parse_args():
  parser=jgtcommon.new_parser("PDS File 2 CDS File",epilog,"pds2cds",add_exiting_quietly_flag=True)
  jgtcommon.add_input_file_argument(parser,add_f_alias=True)
  jgtcommon.add_output_argument(parser)
  jgtcommon.add_bars_amount_V2_arguments(parser)
  jgtcommon.add_tlid_date_to_argumments(parser)
  args=jgtcommon.parse_args(parser)
  return args

def convert_pds_2_cds(pdsfile,cdsfile_out=None,quotescount=-1,tlid_dateto=None,usual_cds_required_bars = 609):

  if not os.path.exists(pdsfile):
    #add .csv to support without extension
    pdsfile=pdsfile+".csv"
  if not os.path.exists(pdsfile):
    print("Error: File not found: "+pdsfile)
    from jgtutils.jgterrorcodes import JGTFILES_EXIT_ERROR_CODE
    exit(JGTFILES_EXIT_ERROR_CODE)
  df=pd.read_csv(pdsfile,index_col=0,parse_dates=True)
  if tlid_dateto:
    df=df.loc[:tlid_dateto]
  if quotescount>0:    
    df=df.tail(quotescount+usual_cds_required_bars)
  cdsfile=cdsfile_out if cdsfile_out else pdsfile.replace(".csv",".cds.csv")
  cdf=cds.createFromDF(df)
  cdf.to_csv(cdsfile)
  return cdsfile

def main():
  args=_parse_args()
  convert_pds_2_cds(args.input_file,args.output,args.quotescount,args.tlid_dateto)
  
if __name__ == "__main__":
  main()
  